flexible_table library

Classes

FlexCellBuilder
Builder for building any type of cell within the FlexTable. In general, you will want to extend either the FlexDataCellBuilder or FlexHeaderCellBuilder rather than this class as those are the two classes required by the FlexTable itself.
FlexDataCellBuilder
Builder for data cells within the FlexTable. The default implementation provides no additional functionality over the FlexCellBuilder and exists solely so the header cells and data cells have fully distinct classes to prevent accidental mix ups.
FlexDefaultHeaderDividerBuilder
Builds a divider between the table headers. The divider is the draggable portion that allows for resizing the columns.
FlexFilterController<F>
Controller to use to be able to filter by column values. Be sure to dispose the filter when it is no longer required to prevent memory leaks.
FlexFilterHeaderCellBuilder
Builder for FlexTable headers that utilize a popover to allow for filtering the contents based on a particular value.
FlexHeaderCellBuilder
Builder for data cells within the FlexTable. The default implementation provides no additional functionality over the FlexCellBuilder and exists solely so the header cells and data cells have fully distinct classes to prevent accidental mix ups.
FlexHeaderDividerBuilder
Builds a divider between the table headers. The divider is the draggable portion that allows for resizing the columns.
FlexSortController
Controller for being able to sort rows by the values in a single column.
FlexSortHeaderCellBuilder
Builder to build headers for a FlexTable that allow for sorting a column.
FlexStripeCellBuilder
Builder to use to build data cells that alternate in color by rows.
FlexTable
Table that is higly performant regardless of the number of rows and allows for fully resizable columns.
FlexTableCell
FlexTableColumnSize
Defines the initial sizes for the columns within a FlexTable.
FlexTableController
Controller to provide programmatic control over a FlexTable.
FlexTableRow
Defines a single row of data within a FlexTable.

Typedefs

FlexTableFilterer = bool Function(String filter, String value)
A type definition for a function that can perform a filter. This function should return true when a value should be filtered (removed) from the result set and false if the value should remain in the result set.
FlexTableSorter = int Function(bool ascending, String a, String b)
A type definition for a function that can perform value sorting. The returned value must be 0 if the values are considered equal, <0 if the a value is less than the b value and >0 if the a value is greater than the b value.