FlexCellBuilder class abstract

Builder for building any type of cell within the FlexTable. In general, you will want to extend either the FlexDataCellBuilder or FlexHeaderCellBuilder rather than this class as those are the two classes required by the FlexTable itself.

See also

Implementers

Constructors

FlexCellBuilder({Alignment alignment = Alignment.centerLeft, Color? color, int maxLines = 1, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 8.0), Color? selectedColor})
Defines the alignment of the content within the cell, the maximum number of lines allowed for the Text within the cell, the background color of the cell and the cell's internal padding.
const

Properties

alignment Alignment
final
color Color?
final
hashCode int
The hash code for this object.
no setterinherited
maxLines int
final
padding EdgeInsetsGeometry
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedColor Color?
final

Methods

build({required Widget child, required BuildContext context, required int columnIndex, required int rowIndex, required bool selected}) Widget
Builds the Widget for the cell located at columnIndex and rowIndex. The passed in child should be wrapped by whatever widgets this builder provides.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited