Builder for building any type of cell within the FlexTable. In general,
you will want to extend either the FlexDataCellBuilder or
FlexHeaderCellBuilder rather than this class as those are the two classes
required by the FlexTable itself.
Builder for data cells within the FlexTable. The default implementation
provides no additional functionality over the FlexCellBuilder and exists
solely so the header cells and data cells have fully distinct classes to
prevent accidental mix ups.
Builder for data cells within the FlexTable. The default implementation
provides no additional functionality over the FlexCellBuilder and exists
solely so the header cells and data cells have fully distinct classes to
prevent accidental mix ups.
A type definition for a function that can perform a filter. This function
should return true when a value should be filtered (removed) from the
result set and false if the value should remain in the result set.
A type definition for a function that can perform value sorting. The
returned value must be 0 if the values are considered equal, <0 if the
a value is less than the b value and >0 if the a value is greater than
the b value.