FlexHeaderCellBuilder class
Builder for data cells within the FlexTable. The default implementation provides no additional functionality over the FlexCellBuilder and exists solely so the header cells and data cells have fully distinct classes to prevent accidental mix ups.
See also:
- Inheritance
-
- Object
- FlexCellBuilder
- FlexHeaderCellBuilder
- Implementers
Constructors
- FlexHeaderCellBuilder({Alignment alignment = Alignment.centerLeft, Color? color, int maxLines = 1, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 8.0)})
-
const
Properties
- alignment → Alignment
-
finalinherited
- color → Color?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLines → int
-
finalinherited
- padding → EdgeInsetsGeometry
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedColor → Color?
-
finalinherited
Methods
-
build(
{required Widget child, required BuildContext context, required int columnIndex, required int rowIndex, required bool selected}) → Widget -
Builds the Widget for the cell located at
columnIndexandrowIndex. The passed inchildshould be wrapped by whatever widgets this builder provides.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited